"""
Tests of the EventArray class
"""

try:
    import unittest2 as unittest
except ImportError:
    import unittest

from neo.core.eventarray import EventArray

class TestEventArray(unittest.TestCase):
    pass


if __name__ == "__main__":
    unittest.main()
